ScreenshotGuardPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ScreenshotGuardPlatform
Implementers

Constructors

ScreenshotGuardPlatform()
Constructs a ScreenshotGuardPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableSecureFlag(bool enable) → Future<void>
Abstract method to enable or disable the secure flag.
getPlatformVersion() → Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ScreenshotGuardPlatform
The default instance of ScreenshotGuardPlatform to use.
getter/setter pair